@@ -1,15 +1,17 @@
 package HTTP::Server::Simple;
-use 5.006;
 use strict;
 use warnings;
+use FileHandle;
 use Socket;
 use Carp;
 
-our $VERSION = '0.18';
+use vars qw($VERSION $bad_request_doc);
+$VERSION = '0.21';
+
 
 =head1 NAME
 
-HTTP::Server::Simple
+HTTP::Server::Simple - Lightweight HTTP server
 
 
 =head1 SYNOPSIS
@@ -161,9 +163,9 @@ sub background {
     my $child = fork;
     die "Can't fork: $!" unless defined($child);
     return $child if $child;
-    use POSIX;
 
     if ( $^O !~ /MSWin32/ ) {
+        require POSIX;
         POSIX::setsid()
             or die "Can't start a new session: $!";
     }
@@ -223,6 +225,7 @@ sub run {
     }
     else {
         $self->setup_listener;
+	$self->after_setup_listener();
         *{"$pkg\::run"} = $self->_default_run;
     }
 
@@ -252,7 +255,7 @@ sub _default_run {
             local $SIG{PIPE} = 'IGNORE';    # If we don't ignore SIGPIPE, a
                  # client closing the connection before we
                  # finish sending will cause the server to exit
-            while ( accept( my $remote, HTTPDaemon ) ) {
+            while ( accept( my $remote = new FileHandle, HTTPDaemon ) ) {
                 $self->stdio_handle($remote);
                 $self->lookup_localhost() unless ($self->host);
                 $self->accept_hook if $self->can("accept_hook");
@@ -421,7 +424,7 @@ of keys of this list.
 =cut
 
 sub setup {
-    my ($self) = @_;
+    my $self = shift;
     while ( my ( $item, $value ) = splice @_, 0, 2 ) {
         $self->$item($value) if $self->can($item);
     }
@@ -586,6 +589,16 @@ sub setup_listener {
 
 }
 
+
+=head2 after_setup_listener
+
+This method is called immediately after setup_listener. It's here just for you to override.
+
+=cut
+
+sub after_setup_listener {
+}
+
 =head2 bad_request
 
 This method should print a valid HTTP response that says that the
@@ -593,7 +606,7 @@ request was invalid.
 
 =cut
 
-our $bad_request_doc = join "", <DATA>;
+$bad_request_doc = join "", <DATA>;
 
 sub bad_request {
     my $self = shift;
